# $Id: ag_i18n_inc_v35.pm,v 1.3 2008/03/10 10:06:45 aatre Exp $
# VT50-2000-2016-84-28-4
# $Copyright: Copyright (c) 2016 Veritas Technologies LLC.
# All rights reserved.
#
# THIS SOFTWARE CONTAINS CONFIDENTIAL INFORMATION AND TRADE SECRETS OF
# VERITAS TECHNOLOGIES LLC.  USE, DISCLOSURE OR REPRODUCTION IS PROHIBITED
# WITHOUT THE PRIOR EXPRESS WRITTEN PERMISSION OF VERITAS TECHNOLOGIES LLC.
#
# The  Licensed  Software  and  Documentation  are  deemed  to be commercial
# computer  software  as  defined  in  FAR  12.212 and subject to restricted
# rights  as  defined in FAR Section 52.227-19 "Commercial Computer Software
# - Restricted  Rights"  and  DFARS 227.7202,  et seq.  "Commercial Computer
# Software  and  Commercial Computer Software Documentation," as applicable,
# and any successor regulations, whether delivered by Veritas as on premises
# or  hosted  services.  Any  use,  modification,  reproduction  release,
# performance,  display  or  disclosure  of  the  Licensed  Software  and
# Documentation by the U.S. Government shall be solely in accordance with
# the terms of this Agreement. $
#
# exported functions can be used after doing the following:
#       use ag_i18n_inc;

package ag_i18n_inc;
use Exporter;
@ISA = ('Exporter');
@EXPORT = ('$VCSAG_RES_UNKNOWN', '$VCSAG_RES_OFFLINE', '$VCSAG_RES_ONLINE', 'VCSAG_SET_ENVS', 'VCSAG_LOG_MSG', 'VCSAG_LOGDBG_MSG', 'VCSAG_SQUEEZE_SPACES');
use File::Basename;
use POSIX qw(uname);
use strict;

my ($ACTION_ENTRY_PT) = "actions";
my ($VCSHOME, $HALOG, $SYSTEM, $FILE_NAME, $AGENT_DIR, $VCSAG_OS);
my ($VCS_LOG_CATEGORY, $VCS_LOG_SCRIPT_NAME, $VCS_LOG_AGENT_NAME);
my ($VCS_SUPPLANG, $VCS_USERLANG) = ("C", $ENV{"LANG"});
#our($VCSAG_RES_UNKNOWN, $VCSAG_RES_OFFLINE, $VCSAG_RES_ONLINE) = (99, 100, 110);
my($VCSAG_RES_UNKNOWN, $VCSAG_RES_OFFLINE, $VCSAG_RES_ONLINE) = (99, 100, 110);

$VCSHOME = $ENV{"VCS_HOME"};
$VCSHOME = "/opt/VRTSvcs" unless (defined ($VCSHOME));
$HALOG = "$VCSHOME/bin/halog";
$VCSAG_OS = "UNIX";

$FILE_NAME = $0;

# set entry point
$VCS_LOG_SCRIPT_NAME = basename ($FILE_NAME);

# set agent name
$AGENT_DIR = dirname ($FILE_NAME);
$VCS_LOG_AGENT_NAME = basename ($AGENT_DIR);

# special treatment to action entry point
if ($VCS_LOG_AGENT_NAME eq $ACTION_ENTRY_PT)
{
    $VCS_LOG_SCRIPT_NAME = $VCS_LOG_AGENT_NAME;
    $AGENT_DIR = dirname (dirname ($FILE_NAME));
    $VCS_LOG_AGENT_NAME = basename ($AGENT_DIR);
}

# set category-id
($SYSTEM) = uname ();
if ($SYSTEM eq "AIX")
{
    $VCS_LOG_CATEGORY = 10011;
}
elsif ($SYSTEM eq "HP-UX")
{
    $VCS_LOG_CATEGORY = 10021;
    $ENV{"LANG"} = $VCS_SUPPLANG;
}
elsif ($SYSTEM eq "Linux")
{
    $VCS_LOG_CATEGORY = 10031;
    $ENV{"LANG"} = $VCS_SUPPLANG;
}
elsif ($SYSTEM eq "SunOS")
{
    $VCS_LOG_CATEGORY = 10001;
}
else # if ($SYSTEM eq "Windows NT")
{
    $VCS_LOG_CATEGORY = 10041;
    $HALOG = "\"$VCSHOME\\bin\\halog\"";
    $VCSAG_OS = "WINDOWS";

    $VCS_LOG_SCRIPT_NAME =~ s/\.pl$//;
}

if ($VCSAG_OS eq "UNIX")
{
    my ($PATH) = $ENV{PATH};
    $PATH = "/usr/bin:/bin:/usr/sbin:/sbin:$PATH";
    $ENV{PATH} = $PATH;
}

$ENV{VCS_LOG_AGENT_NAME} = $VCS_LOG_AGENT_NAME;
$ENV{VCS_LOG_SCRIPT_NAME} = $VCS_LOG_SCRIPT_NAME;
$ENV{VCS_LOG_CATEGORY} = $VCS_LOG_CATEGORY;


# set the environment variables required for logging.
# this function must be called once before calling the
# logging function VCSAG_LOG_MSG/VCSAG_LOGDBG_MSG
#
# usage:
# 0. VCSAG_SET_ENVS () # only for triggers
# 1. VCSAG_SET_ENVS ($resource_name)
# 2. VCSAG_SET_ENVS ($resource_name, $category)
# 3. VCSAG_SET_ENVS ($resource_name, $entry_point)
# 4. VCSAG_SET_ENVS ($resource_name, $category, $entry_point)
# 5. VCSAG_SET_ENVS ($resource_name, $entry_point, $category)
sub VCSAG_SET_ENVS
{
    # resource name and/or category and/or entry point.
    # passed by caller [optional]
    my ($VCS_LOG_RESOURCE_NAME, $OPT_ARG1, $OPT_ARG2) = @_;

    if ($#_ == -1) # for triggers
    {
        $ENV{VCS_LOG_CATEGORY} = 6;
        $ENV{VCS_LOG_AGENT_NAME} = "";
        return;
    }

    $ENV{VCS_LOG_RESOURCE_NAME} = $VCS_LOG_RESOURCE_NAME;

    if ($OPT_ARG1)
    {
        if ($OPT_ARG1 !~ /\D/)
        {
            $ENV{VCS_LOG_CATEGORY} = $OPT_ARG1;
        }
        elsif ($OPT_ARG1 !~ /[^a-z]/)
        {
            $ENV{VCS_LOG_SCRIPT_NAME} = $OPT_ARG1;
        }
    }

    if ($OPT_ARG2)
    {
        if ($OPT_ARG2 !~ /\D/)
        {
            $ENV{VCS_LOG_CATEGORY} = $OPT_ARG2;
        }
        elsif ($OPT_ARG2 !~ /[^a-z]/)
        {
            $ENV{VCS_LOG_SCRIPT_NAME} = $OPT_ARG2;
        }
    }
}


# all perl entry points must use this function if it is not a debug msg.
#
# usage:
# 1. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>)
# 2. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>, "$param1")
# 3. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>, "-encoding <encoding>")
# 4. VCSAG_LOG_MSG ("<sev>", "<msg>", <msgid>, "-encoding <encoding>", "$param1")
#
# example:
# 1. VCSAG_LOG_MSG ("N", "a test message", 1);
# 2. VCSAG_LOG_MSG ("N", "a test message of $test", 1, "$test")
# 3. VCSAG_LOG_MSG ("N", "a test message", 1, "-encoding utf8")
# 4. VCSAG_LOG_MSG ("N", "a test message of $test", 1, "-encoding utf8", "$test")
sub VCSAG_LOG_MSG
{
    # @params includes "-encoding <encoding>" and all the parameters.
    # caller needs to make sure that it has passed the parameters in
    # the correct order.
    # if <encoding> is passed as an argument then the format of the
    # params would be :
    # $params[0] = "-encoding <encoding>"
    # $params[1] = <param1>
    # $params[2] = <param2> and so on.
    # otherwise :
    # $params[0] = <param1>
    # $params[1] = <param2> and so on.
    my ($severity, $msg, $msgid, @params) = @_;
    my ($i, $log_msg) = (0, "");
    my ($encoding, $param_idx, $parameters) = ("", 0, "", "");

    if ($#params >= 0)
    {
        $encoding = $params[0] if ($params[0] =~ /^\s*-encoding\s/);
    }
    $param_idx = 1 if ($encoding);

    for ($i = $param_idx; $i <= $#params; $i++)
    {
        $params[$i] = "%$params[$i]" if ($params[$i] =~ /^-/);
        $parameters .= "\"$params[$i]\" ";
    }

  #------------------------
  # VCS 3.5 halog tags:
  # TAG A => SEV C
  # TAG B => SEV E
  # TAG C => SEV W
  # TAG D => SEV N
  # TAG E => SEV I
  #------------------------

  my %shTagLookup = ();
  $shTagLookup{"C"} = "A";
  $shTagLookup{"E"} = "B";
  $shTagLookup{"W"} = "C";
  $shTagLookup{"N"} = "D";
  $shTagLookup{"I"} = "E";

    $parameters = "-parameters " . "$parameters" if ("$parameters");
    $log_msg = "$HALOG -add $shTagLookup{$severity} \"$msg\" -msgid $msgid";
    $log_msg .= " $encoding $parameters";

    if ($VCSAG_OS eq "UNIX")
    {
        system ($log_msg);
    }
    else # if ($VCSAG_OS eq "WINDOWS")
    {
        system ("\"$log_msg\"");
    }
}


# all perl entry points must use this function if it is not a debug msg.
#
# usage:
# 1. VCSAG_LOGDBG_MSG (<dbg>, "<msg>")
# 2. VCSAG_LOGDBG_MSG (<dbg>, "<msg>", <msgid>)
# 3. VCSAG_LOGDBG_MSG (<dbg>, "<msg>", <msgid>, "$param1")
# 4. VCSAG_LOGDBG_MSG (<dbg>, "<msg>", <msgid>, "-encoding <encoding>")
# 5. VCSAG_LOGDBG_MSG (<dbg>, "<msg>", <msgid>, "-encoding <encoding>", "$param1")
#
# example:
# 1. VCSAG_LOGDBG_MSG (1, "a test message")
# 2. VCSAG_LOGDBG_MSG (1, "a test message", 1)
# 3. VCSAG_LOGDBG_MSG (1, "a test message of $test", 1, "$test")
# 4. VCSAG_LOGDBG_MSG (1, "a test message", 1, "-encoding utf8");
# 5. VCSAG_LOGDBG_MSG (1, "a test message of $test", 1, "-encoding utf8", "$test")
sub VCSAG_LOGDBG_MSG
{
    # @params includes "-encoding <encoding>" and all the parameters.
    # caller needs to make sure that it has passed the parameters in
    # the correct order.
    # if <encoding> is passed as an argument then the format of the
    # params would be :
    # $params[0] = "-encoding <encoding>"
    # $params[1] = <param1>
    # $params[2] = <param2> and so on.
    # otherwise :
    # $params[0] = <param1>
    # $params[1] = <param2> and so on.
    my ($dbg, $msg, $msgid, @params) = @_;
    my ($i, $log_msg) = (0, "");
    my ($encoding, $param_idx, $parameters) = ("", 0, "", "");

    $log_msg = "$HALOG -add \"$msg\" -dbg $dbg";

    if ($msgid)
    {
        $log_msg .= " -msgid $msgid";

        if ($#params >= 0)
        {
            $encoding = $params[0] if ($params[0] =~ /^\s*-encoding\s/);
        }
        $param_idx = 1 if ($encoding);

        for ($i = $param_idx; $i <= $#params; $i++)
        {
            $params[$i] = "%$params[$i]" if ($params[$i] =~ /^-/);
            $parameters .= "\"$params[$i]\" ";
        }

        $parameters = "-parameters " . "$parameters" if ("$parameters");
        $log_msg .= " $encoding $parameters";
    }

    if ($VCSAG_OS eq "UNIX")
    {
        system ($log_msg);
    }
    else # if ($VCSAG_OS eq "WINDOWS")
    {
        system ("\"$log_msg\"");
    }
}


# remove leading and trailing spaces & squeeze the spaces
#
# input params :
#   1. strings
#
# output params :
#   1. space squeezed strings
#
# usage:
# 1. ($a, ...) = VCSAG_SQUEEZE_SPACES ($a, ...);
#
# example:
# 1. $str1 = VCSAG_SQUEEZE_SPACES ($str1);
# 2. ($str1, $str2) = VCSAG_SQUEEZE_SPACES ($str1, $str2);
# 3. @str = VCSAG_SQUEEZE_SPACES (@str);
# 4. @str = VCSAG_SQUEEZE_SPACES ($str1, $str2);
sub VCSAG_SQUEEZE_SPACES
{
    my (@string) = @_;
    my ($i);

    return if ($#string == -1);

    for ($i = 0; $i <= $#string; $i++)
    {
        $string[$i] =~ s/\s+/ /g;
        $string[$i] =~ s/^\s+//g;
        $string[$i] =~ s/\s+$//g;
    }

    return ($#string == 0) ? $string[0] : @string;
}

1;
